Clojure only.

timewords.fuzzy.fuzzy


to-dateclj

(to-date fuzzy-date & [language document-time])

Parses string dates into components represented by numeric values: 1-12 for months 1-31 for days 19??-20?? for years.

Dispatches parsing by language. Default language is en.

Parses string dates into components represented by numeric values:
1-12 for months
1-31 for days
19??-20?? for years.

Dispatches parsing by language. Default language is en.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries