Clojure only.

timewords.fuzzy.lt.utils


cleanclj

(clean d)

Remove all language specific patterns which usualy accompany publication date

Remove all language specific patterns which usualy accompany publication date
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries