(to-date fuzzy-date & [language document-time])Parses string dates into components represented by numeric values: 1-12 for months 1-31 for days 19??-20?? for years.
Dispatches parsing by language. Default language is en.
Parses string dates into components represented by numeric values: 1-12 for months 1-31 for days 19??-20?? for years. Dispatches parsing by language. Default language is en.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |